@@ -34,23 +34,26 @@ class BaseTable:
         meta.create_all(self.engine)
 
     def insert(self, values, keys=None, *args, **kwargs):
-        cols = [col.name for col in self.table.columns]
-        if isinstance(values, dict):
-            values = dict([(k, v) for k, v in values.items() if k in cols])
-        elif isinstance(values, list):
-            if isinstance(values[0], dict):
-                values = [dict([(k, v) for k, v in item.items() if k in cols]) for item in values]
-            elif isinstance(values[0], list):
-                values = [dict(zip(keys, item)) for item in values]
+        try:
+            cols = [col.name for col in self.table.columns]
+            if isinstance(values, dict):
+                values = dict([(k, v) for k, v in values.items() if k in cols])
+            elif isinstance(values, list):
+                if isinstance(values[0], dict):
+                    values = [dict([(k, v) for k, v in item.items() if k in cols]) for item in values]
+                elif isinstance(values[0], list):
+                    values = [dict(zip(keys, item)) for item in values]
 
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore")
-            # code here...
-            if str(self.engine.url).startswith('sqlite'):
-                ins = self.table.insert(values=values).prefix_with("OR IGNORE")
-            else:
-                ins = self.table.insert(values=values).prefix_with("IGNORE")
-            self.engine.execute(ins)
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
+                # code here...
+                if str(self.engine.url).startswith('sqlite'):
+                    ins = self.table.insert(values=values).prefix_with("OR IGNORE")
+                else:
+                    ins = self.table.insert(values=values).prefix_with("IGNORE")
+                self.engine.execute(ins)
+        except Exception as e:
+            print(e)
 
     def select_all(self):
         return self.engine.execute(select([self.table]))
