@@ -106,22 +106,18 @@ class DataFileProperty:
 
         logger.info(f'download for {file_pro.file_path_tar(absolute=False)}')
         if self.data_type == 'kline':
-            exchan = LoadDataKline(self.exchange)
+            exchan = LoadDataKline(self.exchange, csv_path=file_pro.file_path_csv())
         else:
-            exchan = LoadTradeKline(self.exchange)
-        exchan.table.delete_all()
+            exchan = LoadTradeKline(self.exchange, csv_path=file_pro.file_path_csv())
         unix_start, unix_end = int(file_pro.start_date.timestamp() * 1000), int(file_pro.end_date.timestamp() * 1000)
         # 下载
         exchan.load_all(timeframe=file_pro.timeframe, unix_start=unix_start,
-                        unix_end=unix_end, csv_path=file_pro.file_path_csv())
-        # 保存
-        exchan.table.to_csv_all(file_pro.file_path_csv(), page_size=100000)
+                        unix_end=unix_end)
         # 压缩
         with tarfile.open(file_pro.file_path_tar(), "w:xz") as tar:
             tar.add(file_pro.file_path_csv(), arcname=file_pro.arcname(file_pro.file_path_csv()))
         # 删除
         os.remove(file_pro.file_path_csv())
-        exchan.table.delete_all()
         return True
 
     def _merge_and_save(self, file_pro: FileProperty) -> bool:
