@@ -4,10 +4,9 @@ import logging
 import time
 from datetime import datetime
 
-import ccxt  # noqa: E402
+import ccxt
 import pandas as pd
 from ccxt.base.exchange import Exchange
-from notecoin.base.database import KlineData
 from tqdm import tqdm
 
 logger = logging.getLogger()
@@ -16,20 +15,25 @@ one_hour = 3600 * 1000
 
 
 class LoadDataKline:
-    def __init__(self, exchange: Exchange, suffix="com", *args, **kwargs):
-        self.table = KlineData(prefix=exchange.name, suffix=suffix)
+    def __init__(self, exchange: Exchange, csv_path, *args, **kwargs):
+        self.csv_path = csv_path
         self.exchange = exchange
         super(LoadDataKline, self).__init__(*args, **kwargs)
 
     def load_all(self, *args, **kwargs):
         self.exchange.load_markets()
-        pbr = tqdm(self.exchange.symbols)
-        for sym in pbr:
-            if ':' not in sym:
-                pbr.set_description(sym)
-                self.load(sym, *args, **kwargs)
+        with open(self.csv_path, mode="w") as csv_f:
+            csv_writer = csv.DictWriter(csv_f, delimiter=",",
+                                        fieldnames=["symbol", "timestamp", "open", "close", "low", "high", "vol"])
+            csv_writer.writeheader()
 
-    def _load(self, symbol, fetch_since, timeframe='1m', limit=100, try_times=3, *args, **kwargs):
+            pbr = tqdm(self.exchange.symbols)
+            for sym in pbr:
+                if ':' not in sym:
+                    pbr.set_description(sym)
+                    self.load(sym, csv_writer=csv_writer, *args, **kwargs)
+
+    def _load(self, symbol, fetch_since, csv_writer, timeframe='1m', limit=100, try_times=3, *args, **kwargs):
         if try_times <= 0:
             return False, None
 
@@ -41,60 +45,27 @@ class LoadDataKline:
 
             df = pd.DataFrame(result, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
             df['symbol'] = symbol
-            self.table.insert(json.loads(df.to_json(orient='records')))
+            csv_writer.writerows(json.loads(df.to_json(orient='records')))
             time.sleep(int(self.exchange.rateLimit / 1000))
             return True, result
         except Exception as e:
-            return self._load(symbol, fetch_since, timeframe, limit=limit, try_times=try_times - 1, *args, **kwargs)
+            return self._load(symbol, fetch_since, csv_writer, timeframe, limit=limit, try_times=try_times - 1, *args,
+                              **kwargs)
 
-    def load(self, symbol, unix_start, unix_end, timeframe='1m', limit=100, *args, **kwargs):
-        unix_max, unix_min = self.table.select_symbol_maxmin(symbol)
+    def load(self, symbol, unix_start, unix_end, csv_writer, timeframe='1m', limit=100, *args, **kwargs):
         unix_delta = limit * self.exchange.parse_timeframe(timeframe) * 1000
-
-        unix_start = unix_start
-        unix_end = unix_end
-        unix_max = unix_max or unix_end
-        unix_min = unix_min or unix_end
-
-        if abs((unix_max - unix_min) / unix_delta) > 100:
-            if unix_min >= unix_start:
-                unix_temp = unix_min
-                pbar = tqdm(range(unix_min, unix_start, -unix_delta), desc=symbol)
-                for _ in pbar:
-                    status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
-                    if status is False:
-                        break
-                    pbar.set_postfix({'time': datetime.fromtimestamp(result[0][0] // 1000)})
-                    unix_temp = result[0][0]
-
-            if unix_max >= unix_end:
-                unix_temp = unix_max
-                pbar = tqdm(range(unix_max, unix_end, unix_delta), desc=symbol)
-                for _ in pbar:
-                    status, result = self._load(symbol, unix_temp, timeframe=timeframe, limit=limit)
-                    if status is False:
-                        break
-                    unix_temp = result[-1][0]
-        else:
-            if unix_min >= unix_start:
-                unix_temp = unix_min
-                for _ in range(unix_min, unix_start, -unix_delta):
-                    status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
-                    if status is False:
-                        break
-                    unix_temp = result[0][0]
-
-            if unix_max >= unix_end:
-                unix_temp = unix_max
-                for _ in range(unix_max, unix_end, unix_delta):
-                    status, result = self._load(symbol, unix_temp, timeframe=timeframe, limit=limit)
-                    if status is False:
-                        break
-                    unix_temp = result[-1][0]
+        unix_temp = unix_start
+        pbar = tqdm(range(unix_end, unix_start, -unix_delta), desc=symbol)
+        for _ in pbar:
+            status, result = self._load(symbol, unix_temp - unix_delta, csv_writer, timeframe=timeframe, limit=limit)
+            if status is False:
+                break
+            pbar.set_postfix({'time': datetime.fromtimestamp(result[0][0] // 1000)})
+            unix_temp = result[0][0]
 
 
 class LoadTradeKline:
-    def __init__(self, exchange: Exchange, csv_path='trade.csv', *args, **kwargs):
+    def __init__(self, exchange: Exchange, csv_path, *args, **kwargs):
         self.exchange = exchange
         self.csv_path = csv_path
         self.csv_writer = None
@@ -141,10 +112,15 @@ class LoadTradeKline:
 
                 time.sleep(int(self.exchange.rateLimit / 1000))
                 if len(result) > 30000:
-                    csv_writer.writerows(result)
+                    self.write_data(csv_writer, result, unix_end)
                     result.clear()
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
         if len(result) > 0:
-            csv_writer.writerows(result)
+            self.write_data(csv_writer, result, unix_end)
+
+    def write_data(self, csv_writer, data_list, unix_end):
+        df = pd.DataFrame(data_list)
+        df = df[df['timestamp'] <= unix_end]
+        csv_writer.writerows(json.loads(df.to_json(orient='records')))
